// src/use-radio-group.ts
import { radioGroup } from "@nextui-org/theme";
import { useMemo } from "react";
import { useRadioGroupState } from "@react-stately/radio";
import { useRadioGroup as useReactAriaRadioGroup } from "@react-aria/radio";
import { useDOMRef } from "@nextui-org/dom-utils";
import { clsx } from "@nextui-org/shared-utils";
import { mergeProps } from "@react-aria/utils";
function useRadioGroup(props) {
  const {
    as,
    ref,
    classNames,
    children,
    label,
    size = "md",
    color = "primary",
    radius = "full",
    isDisabled = false,
    disableAnimation = false,
    orientation = "vertical",
    isRequired = false,
    validationState,
    className,
    onChange,
    onValueChange,
    ...otherProps
  } = props;
  const Component = as || "div";
  const domRef = useDOMRef(ref);
  const otherPropsWithOrientation = useMemo(() => {
    return {
      ...otherProps,
      "aria-label": typeof label === "string" ? label : otherProps["aria-label"],
      isRequired,
      orientation,
      onChange: onValueChange
    };
  }, [otherProps, onValueChange]);
  const groupState = useRadioGroupState(otherPropsWithOrientation);
  const { labelProps, radioGroupProps: groupProps } = useReactAriaRadioGroup(
    otherPropsWithOrientation,
    groupState
  );
  const context = useMemo(
    () => ({
      size,
      color,
      radius,
      groupState,
      isRequired,
      validationState,
      isDisabled,
      disableAnimation,
      onChange
    }),
    [
      size,
      color,
      radius,
      groupState,
      isRequired,
      validationState,
      isDisabled,
      disableAnimation,
      onChange
    ]
  );
  const slots = useMemo(() => radioGroup(), []);
  const baseStyles = clsx(classNames == null ? void 0 : classNames.base, className);
  const getGroupProps = () => {
    return {
      ref: domRef,
      className: slots.base({ class: baseStyles }),
      ...mergeProps(groupProps, otherProps)
    };
  };
  const getLabelProps = () => {
    return {
      className: slots.label({ class: classNames == null ? void 0 : classNames.label }),
      ...labelProps
    };
  };
  const getWrapperProps = () => {
    return {
      className: slots.wrapper({ class: classNames == null ? void 0 : classNames.wrapper }),
      role: "presentation",
      "data-orientation": orientation
    };
  };
  return {
    Component,
    children,
    label,
    context,
    getGroupProps,
    getLabelProps,
    getWrapperProps
  };
}

export {
  useRadioGroup
};
